UserInputHandlerFn

Type Alias UserInputHandlerFn 

pub type UserInputHandlerFn = Arc<dyn Fn(UserInputRequest, String) -> Pin<Box<dyn Future<Output = Result<UserInputResponse, CopilotError>> + Send>> + Send + Sync>;
A user input handler is an async function that takes a user input request and returns a response.

Aliased Type

pub struct UserInputHandlerFn { /* private fields */ }