SessionConfig

Struct SessionConfig 

pub struct SessionConfig {
Show 19 fields pub session_id: Option<String>, pub model: Option<String>, pub reasoning_effort: Option<ReasoningEffort>, pub config_dir: Option<String>, pub tools: Option<Vec<ToolDefinition>>, pub system_message: Option<SystemMessageConfig>, pub available_tools: Option<Vec<String>>, pub excluded_tools: Option<Vec<String>>, pub provider: Option<ProviderConfig>, pub working_directory: Option<String>, pub streaming: Option<bool>, pub mcp_servers: Option<HashMap<String, McpServerConfig>>, pub custom_agents: Option<Vec<CustomAgentConfig>>, pub skill_directories: Option<Vec<String>>, pub disabled_skills: Option<Vec<String>>, pub infinite_sessions: Option<InfiniteSessionConfig>, pub request_permission: Option<bool>, pub request_user_input: Option<bool>, pub hooks: Option<bool>,
}
Configuration for creating a session.

This struct holds the parameters sent to the server via session.create. Tool handlers, permission handlers, user input handlers, and hooks are registered separately on the Rust side and are not serialized.

Fields

session_id: Option<String>model: Option<String>reasoning_effort: Option<ReasoningEffort>config_dir: Option<String>tools: Option<Vec<ToolDefinition>>system_message: Option<SystemMessageConfig>available_tools: Option<Vec<String>>excluded_tools: Option<Vec<String>>provider: Option<ProviderConfig>working_directory: Option<String>streaming: Option<bool>mcp_servers: Option<HashMap<String, McpServerConfig>>custom_agents: Option<Vec<CustomAgentConfig>>skill_directories: Option<Vec<String>>disabled_skills: Option<Vec<String>>infinite_sessions: Option<InfiniteSessionConfig>request_permission: Option<bool>

Set by the SDK based on whether handlers are registered (not user-set).

request_user_input: Option<bool>

Set by the SDK based on whether handlers are registered (not user-set).

hooks: Option<bool>

Set by the SDK based on whether hooks are registered (not user-set).