pub type ToolHandler = Arc<dyn Fn(Value, ToolInvocation) -> Pin<Box<dyn Future<Output = Result<Value, CopilotError>> + Send>> + Send + Sync>;Expand description
A tool handler is an async function that takes arguments and invocation info, and returns a result value.
Aliased Type
pub struct ToolHandler { /* private fields */ }